//------------------------------------------------------------
// Copyright (C)2002 Sony Computer Entertainment America Inc.
//
// This file is subject to the terms and conditions of the GNU
// General Public Licence Version 2.  See the file "COPYING"
// in the main directory of this archive for more details.
//------------------------------------------------------------

#ifndef __PS2_OS_H__
#define __PS2_OS_H__

#ifdef __cplusplus
extern "C" {
#endif

//-------------------------------------
enum
{
   OS_RET_OK = 0,
   OS_RET_ERROR,
   OS_RET_INVALIDPARAMETER,

   OS_RET_MAX
};

//-------------------------------------
typedef union
{
   __u32    ui32[4];
   __u64    ui64[2];
   __u128   ui128;
   float    fl32[4];
   double   fl64[2];
   struct
   {
      float  x;
      float  y;
      float  z;
      float  w;
   } XYZWfl;
   struct
   {
      float  r;
      float  g;
      float  b;
      float  a;
   } RGBAfl;
   struct
   {
      __u32  x;
      __u32  y;
      __u32  z;
      __u32  w;
   } XYZWui;
   struct
   {
      __u32  r;
      __u32  g;
      __u32  b;
      __u32  a;
   } RGBAui;
   struct
   {
      float  s;
      float  t;
      float  q;
      float  pad;
   } STQ;
   struct
   {
      __u32  u;
      __u32  v;
      __u32  pad1;
      __u32  pad2;
   } UV;
} OS_Qword __attribute__ ((aligned (16)));

typedef struct
{

} OS_Data;

struct OS_Data
{
   unsigned int  Interlace;                              // Interlace or not
   unsigned int  VideoMode;                              // Vesa, NTSC or PAL
   unsigned int  FrameOrField;                           // Frame or field mode
   unsigned int  RefreshRate;                            // Screen's refresh rate
   unsigned int  FrameDepth;                             // 16, 24 or 32 bit
   unsigned int  ZDepth;                                 // 0, 16 or 24
   unsigned int  ZBit;                                   // 0, 16 or 24
   unsigned int  ScreenResolution;                       // Screen width and height, in pixels
};

//-------------------------------------
unsigned int OS_Init (int argc, char *argv[]);
unsigned int OS_Uninit (void);
unsigned int OS_Update (void);
unsigned int OS_GetOSData (struct OS_Data **osdata);

#ifdef __cplusplus
}
#endif

#endif   // __PS2_OS_H__
